@@ -127,12 +127,8 @@ class GAN(LightningModule):
             # adversarial loss is binary cross-entropy
             g_loss = self.adversarial_loss(self.discriminator(self(z)), valid)
             tqdm_dict = {'g_loss': g_loss}
-            output = OrderedDict({
-                'loss': g_loss,
-                'progress_bar': tqdm_dict,
-                'log': tqdm_dict
-            })
-            return output
+            self.log_dict(tqdm_dict)
+            return g_loss
 
         # train discriminator
         if optimizer_idx == 1:
@@ -154,12 +150,9 @@ class GAN(LightningModule):
             # discriminator loss is the average of these
             d_loss = (real_loss + fake_loss) / 2
             tqdm_dict = {'d_loss': d_loss}
-            output = OrderedDict({
-                'loss': d_loss,
-                'progress_bar': tqdm_dict,
-                'log': tqdm_dict
-            })
-            return output
+            self.log_dict(tqdm_dict)
+
+            return d_loss
 
     def configure_optimizers(self):
         lr = self.lr
