@@ -18,6 +18,7 @@ import inspect
 import os
 from argparse import Namespace
 from typing import Union, Dict, Any, Optional, Callable, MutableMapping
+from warnings import warn
 
 import fsspec
 import torch
@@ -372,10 +373,21 @@ def save_hparams_to_yaml(config_yaml, hparams: Union[dict, Namespace]) -> None:
                     OmegaConf.save(OmegaConf.create(hparams), fp, resolve=True)
                 return
 
-    # saving the standard way
     assert isinstance(hparams, dict)
+    hparams_allowed = {}
+    # drop paramaters which contain some strange datatypes as fsspec
+    for k, v in hparams.items():
+        try:
+            yaml.dump(v)
+        except TypeError as err:
+            warn(f"Skipping '{k}' parameter because it is not possible to safely dump to YAML.")
+            hparams[k] = type(v).__name__
+        else:
+            hparams_allowed[k] = v
+
+    # saving the standard way
     with fs.open(config_yaml, "w", newline="") as fp:
-        yaml.dump(hparams, fp)
+        yaml.dump(hparams_allowed, fp)
 
 
 def convert(val: str) -> Union[int, float, bool, str]:
