@@ -18,25 +18,23 @@ Weights and Biases
 """
 import os
 from argparse import Namespace
-from typing import Optional, List, Dict, Union, Any
+from typing import Any, Dict, List, Optional, Union
 
 import torch.nn as nn
 
 try:
     import wandb
     from wandb.wandb_run import Run
-    _WANDB_AVAILABLE = True
 except ImportError:  # pragma: no-cover
     wandb = None
     Run = None
-    _WANDB_AVAILABLE = False
 
 from pytorch_lightning.loggers.base import LightningLoggerBase, rank_zero_experiment
 from pytorch_lightning.utilities import rank_zero_only
 
 
 class WandbLogger(LightningLoggerBase):
-    """
+    r"""
     Log using `Weights and Biases <https://www.wandb.com/>`_. Install it with pip:
 
     .. code-block:: bash
@@ -51,17 +49,17 @@ class WandbLogger(LightningLoggerBase):
         anonymous: Enables or explicitly disables anonymous logging.
         version: Sets the version, mainly used to resume a previous run.
         project: The name of the project to which this run will belong.
-        tags: Tags associated with this run.
         log_model: Save checkpoints in wandb dir to upload on W&B servers.
-        experiment: WandB experiment object
-        entity: The team posting this run (default: your username or your default team)
-        group: A unique string shared by all runs in a given group
+        experiment: WandB experiment object.
+        \**kwargs: Additional arguments like `entity`, `group`, `tags`, etc. used by
+            :func:`wandb.init` can be passed as keyword arguments in this logger.
 
     Example:
-        >>> from pytorch_lightning.loggers import WandbLogger
-        >>> from pytorch_lightning import Trainer
-        >>> wandb_logger = WandbLogger()
-        >>> trainer = Trainer(logger=wandb_logger)
+
+        from pytorch_lightning.loggers import WandbLogger
+        from pytorch_lightning import Trainer
+        wandb_logger = WandbLogger()
+        trainer = Trainer(logger=wandb_logger)
 
     See Also:
         - `Tutorial <https://app.wandb.ai/cayush/pytorchlightning/reports/
@@ -70,20 +68,20 @@ class WandbLogger(LightningLoggerBase):
 
     """
 
-    def __init__(self,
-                 name: Optional[str] = None,
-                 save_dir: Optional[str] = None,
-                 offline: bool = False,
-                 id: Optional[str] = None,
-                 anonymous: bool = False,
-                 version: Optional[str] = None,
-                 project: Optional[str] = None,
-                 tags: Optional[List[str]] = None,
-                 log_model: bool = False,
-                 experiment=None,
-                 entity=None,
-                 group: Optional[str] = None):
-        if not _WANDB_AVAILABLE:
+    def __init__(
+        self,
+        name: Optional[str] = None,
+        save_dir: Optional[str] = None,
+        offline: bool = False,
+        id: Optional[str] = None,
+        anonymous: bool = False,
+        version: Optional[str] = None,
+        project: Optional[str] = None,
+        log_model: bool = False,
+        experiment=None,
+        **kwargs
+    ):
+        if wandb is None:
             raise ImportError('You want to use `wandb` logger which is not installed yet,'  # pragma: no-cover
                               ' install it with `pip install wandb`.')
         super().__init__()
@@ -91,13 +89,11 @@ class WandbLogger(LightningLoggerBase):
         self._save_dir = save_dir
         self._anonymous = 'allow' if anonymous else None
         self._id = version or id
-        self._tags = tags
         self._project = project
         self._experiment = experiment
         self._offline = offline
-        self._entity = entity
         self._log_model = log_model
-        self._group = group
+        self._kwargs = kwargs
 
     def __getstate__(self):
         state = self.__dict__.copy()
@@ -126,8 +122,7 @@ class WandbLogger(LightningLoggerBase):
                 os.environ['WANDB_MODE'] = 'dryrun'
             self._experiment = wandb.init(
                 name=self._name, dir=self._save_dir, project=self._project, anonymous=self._anonymous,
-                reinit=True, id=self._id, resume='allow', tags=self._tags, entity=self._entity,
-                group=self._group)
+                reinit=True, id=self._id, resume='allow', **self._kwargs)
             # save checkpoints in wandb dir to upload on W&B servers
             if self._log_model:
                 self._save_dir = self._experiment.dir
